@@ -48,7 +48,8 @@ def get(schema, key, user=None):
         user = os.getenv("SUDO_USER", os.getenv("USER", "root"))
 
     subp = subprocess.Popen(
-        ['sudo', '-u', user, 'gsettings', 'get', schema, key],
+        ['sudo', '--preserve-env=DBUS_SESSION_BUS_ADDRESS,XDG_RUNTIME_DIR',
+         '-H', '-u', user, 'gsettings', 'get', schema, key],
         stdout=subprocess.PIPE, stderr=subprocess.PIPE,
         preexec_fn=misc.drop_all_privileges, universal_newlines=True)
     value = subp.communicate()[0].rstrip('\n')
@@ -67,6 +68,8 @@ def get(schema, key, user=None):
     # Parse ints
     if value.isdigit():
         return int(value)
+    if value.startswith('uint32'):  # uint32 100
+        return int(value.split()[1])
 
     # Parse booleans
     if value == 'false':
@@ -87,7 +90,7 @@ def get_list(schema, key, user=None):
         # This only works reliably with int and strings
         elements = eval(value, None, None)
         return elements
-    except:
+    except Exception:
         return
 
 
@@ -103,7 +106,8 @@ def set(schema, key, value, user=None):
         value = "true" if value else "false"
 
     subprocess.call(
-        ['sudo', '-u', user, 'gsettings', 'set', schema, key, str(value)],
+        ['sudo', '--preserve-env=DBUS_SESSION_BUS_ADDRESS,XDG_RUNTIME_DIR',
+         '-H', '-u', user, 'gsettings', 'set', schema, key, str(value)],
         preexec_fn=misc.drop_all_privileges)
 
 
@@ -123,5 +127,6 @@ def unset(schema, key, user=None):
         user = os.getenv("SUDO_USER", os.getenv("USER", "root"))
 
     subprocess.call(
-        ['sudo', '-u', user, 'gsettings', 'reset', schema, key],
+        ['sudo', '--preserve-env=DBUS_SESSION_BUS_ADDRESS,XDG_RUNTIME_DIR',
+         '-H', '-u', user, 'gsettings', 'reset', schema, key],
         preexec_fn=misc.drop_all_privileges)
